package pl.edu.pwr.tkubik.books;

import java.sql.SQLException;

import org.h2.tools.Server;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.CommandLineRunner;
import org.springframework.boot.SpringApplication;
import org.springframework.boot.autoconfigure.SpringBootApplication;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.ComponentScan;

import pl.edu.pwr.tkubik.books.model.Author;
import pl.edu.pwr.tkubik.books.service.AuthorService;
import pl.edu.pwr.tkubik.books.service.BookService;
import pl.edu.pwr.tkubik.books.service.UserService;

@SpringBootApplication
//@ComponentScan(basePackages = { "pl.edu.pwr.tkubik.books.service"})
public class SimpleJpaBooksApplication implements CommandLineRunner {

	private final AuthorService authorService;
	private final BookService bookService;
	private final UserService userService;

	@Autowired
	public SimpleJpaBooksApplication(AuthorService authorService, BookService bookService, UserService userService) {
		this.authorService = authorService;
		this.bookService = bookService;
		this.userService = userService;
		
	}
	
	public static void main(String[] args) {
		SpringApplication.run(SimpleJpaBooksApplication.class, args);
	}

	@Override
	public void run(String... args) throws Exception {
		Author a = new Author();
		a.setName("John");	
		a = authorService.addAuthor(a);
		a.setName("Adam");
		authorService.updateAuthor(a);
	}

	/**
     * Start internal H2 server so we can query the DB from IDE
     *
     * @return H2 Server instance
     * @throws SQLException
     */
    @Bean(initMethod = "start", destroyMethod = "stop")
    public Server h2Server() throws SQLException {
        return Server.createTcpServer("-tcp", "-tcpAllowOthers", "-tcpPort", "9092");
    }
}
